summaryrefslogtreecommitdiffstats
path: root/vm/mterp
diff options
context:
space:
mode:
authorSteve Block <steveblock@google.com>2012-01-06 19:16:58 +0000
committerSteve Block <steveblock@google.com>2012-01-08 11:26:30 +0000
commitc1a4ab9c313d8a3d12007f2dbef7b5a6fa4ac2ef (patch)
tree76e90a6ae1910835a56e4dad3f60f42392645703 /vm/mterp
parente8e1ddccd616e8226b7cc1e4e9fdb327429249e8 (diff)
downloadandroid_dalvik-c1a4ab9c313d8a3d12007f2dbef7b5a6fa4ac2ef.tar.gz
android_dalvik-c1a4ab9c313d8a3d12007f2dbef7b5a6fa4ac2ef.tar.bz2
android_dalvik-c1a4ab9c313d8a3d12007f2dbef7b5a6fa4ac2ef.zip
Rename (IF_)LOGE(_IF) to (IF_)ALOGE(_IF) DO NOT MERGE
See https://android-git.corp.google.com/g/#/c/157220 Also fix an occurrence of LOGW missed in an earlier change. Bug: 5449033 Change-Id: I2e3b23839e6dcd09015d6402280e9300c75e3406
Diffstat (limited to 'vm/mterp')
-rw-r--r--vm/mterp/Mterp.cpp6
-rw-r--r--vm/mterp/c/OP_UNUSED_FF.cpp2
-rw-r--r--vm/mterp/c/gotoTargets.cpp6
-rw-r--r--vm/mterp/c/header.cpp10
-rw-r--r--vm/mterp/common/asm-constants.h6
-rw-r--r--vm/mterp/out/InterpC-allstubs.cpp18
-rw-r--r--vm/mterp/out/InterpC-armv5te-vfp.cpp10
-rw-r--r--vm/mterp/out/InterpC-armv5te.cpp10
-rw-r--r--vm/mterp/out/InterpC-armv7-a-neon.cpp10
-rw-r--r--vm/mterp/out/InterpC-armv7-a.cpp10
-rw-r--r--vm/mterp/out/InterpC-portable.cpp18
-rw-r--r--vm/mterp/out/InterpC-x86-atom.cpp16
-rw-r--r--vm/mterp/out/InterpC-x86.cpp16
13 files changed, 69 insertions, 69 deletions
diff --git a/vm/mterp/Mterp.cpp b/vm/mterp/Mterp.cpp
index 9f9556f3b..b5cb9a528 100644
--- a/vm/mterp/Mterp.cpp
+++ b/vm/mterp/Mterp.cpp
@@ -41,7 +41,7 @@ bool dvmCheckAsmConstants()
#include "mterp/common/asm-constants.h"
if (failed) {
- LOGE("Please correct the values in mterp/common/asm-constants.h");
+ ALOGE("Please correct the values in mterp/common/asm-constants.h");
dvmAbort();
}
@@ -56,8 +56,8 @@ bool dvmCheckAsmConstants()
int interpSize = (uintptr_t) dvmAsmInstructionEnd -
(uintptr_t) dvmAsmInstructionStart;
if (interpSize != 0 && interpSize != kNumPackedOpcodes*width) {
- LOGE("ERROR: unexpected asm interp size %d", interpSize);
- LOGE("(did an instruction handler exceed %d bytes?)", width);
+ ALOGE("ERROR: unexpected asm interp size %d", interpSize);
+ ALOGE("(did an instruction handler exceed %d bytes?)", width);
dvmAbort();
}
#endif
diff --git a/vm/mterp/c/OP_UNUSED_FF.cpp b/vm/mterp/c/OP_UNUSED_FF.cpp
index f4743db9b..1348aec93 100644
--- a/vm/mterp/c/OP_UNUSED_FF.cpp
+++ b/vm/mterp/c/OP_UNUSED_FF.cpp
@@ -2,7 +2,7 @@ HANDLE_OPCODE(OP_UNUSED_FF)
/*
* In portable interp, most unused opcodes will fall through to here.
*/
- LOGE("unknown opcode 0x%02x\n", INST_INST(inst));
+ ALOGE("unknown opcode 0x%02x\n", INST_INST(inst));
dvmAbort();
FINISH(1);
OP_END
diff --git a/vm/mterp/c/header.cpp b/vm/mterp/c/header.cpp
index 44d706413..d0e55f5ea 100644
--- a/vm/mterp/c/header.cpp
+++ b/vm/mterp/c/header.cpp
@@ -95,7 +95,7 @@
{ \
char* desc; \
desc = dexProtoCopyMethodDescriptor(&curMethod->prototype); \
- LOGE("Invalid branch %d at 0x%04x in %s.%s %s", \
+ ALOGE("Invalid branch %d at 0x%04x in %s.%s %s", \
myoff, (int) (pc - curMethod->insns), \
curMethod->clazz->descriptor, curMethod->name, desc); \
free(desc); \
@@ -314,14 +314,14 @@ static inline bool checkForNull(Object* obj)
}
#ifdef WITH_EXTRA_OBJECT_VALIDATION
if (!dvmIsHeapAddress(obj)) {
- LOGE("Invalid object %p", obj);
+ ALOGE("Invalid object %p", obj);
dvmAbort();
}
#endif
#ifndef NDEBUG
if (obj->clazz == NULL || ((u4) obj->clazz) <= 65536) {
/* probable heap corruption */
- LOGE("Invalid object class %p (in %p)", obj->clazz, obj);
+ ALOGE("Invalid object class %p (in %p)", obj->clazz, obj);
dvmAbort();
}
#endif
@@ -346,14 +346,14 @@ static inline bool checkForNullExportPC(Object* obj, u4* fp, const u2* pc)
}
#ifdef WITH_EXTRA_OBJECT_VALIDATION
if (!dvmIsHeapAddress(obj)) {
- LOGE("Invalid object %p", obj);
+ ALOGE("Invalid object %p", obj);
dvmAbort();
}
#endif
#ifndef NDEBUG
if (obj->clazz == NULL || ((u4) obj->clazz) <= 65536) {
/* probable heap corruption */
- LOGE("Invalid object class %p (in %p)", obj->clazz, obj);
+ ALOGE("Invalid object class %p (in %p)", obj->clazz, obj);
dvmAbort();
}
#endif
diff --git a/vm/mterp/common/asm-constants.h b/vm/mterp/common/asm-constants.h
index b6d82d6ac..bbc043cb3 100644
--- a/vm/mterp/common/asm-constants.h
+++ b/vm/mterp/common/asm-constants.h
@@ -12,19 +12,19 @@
*/
# define MTERP_OFFSET(_name, _type, _field, _offset) \
if (OFFSETOF_MEMBER(_type, _field) != _offset) { \
- LOGE("Bad asm offset %s (%d), should be %d", \
+ ALOGE("Bad asm offset %s (%d), should be %d", \
#_name, _offset, OFFSETOF_MEMBER(_type, _field)); \
failed = true; \
}
# define MTERP_SIZEOF(_name, _type, _size) \
if (sizeof(_type) != (_size)) { \
- LOGE("Bad asm sizeof %s (%d), should be %d", \
+ ALOGE("Bad asm sizeof %s (%d), should be %d", \
#_name, (_size), sizeof(_type)); \
failed = true; \
}
# define MTERP_CONSTANT(_name, _value) \
if ((_name) != (_value)) { \
- LOGE("Bad asm constant %s (%d), should be %d", \
+ ALOGE("Bad asm constant %s (%d), should be %d", \
#_name, (_value), (_name)); \
failed = true; \
}
diff --git a/vm/mterp/out/InterpC-armv5te-vfp.cpp b/vm/mterp/out/InterpC-armv5te-vfp.cpp
index 01246ae33..406bcaed1 100644
--- a/vm/mterp/out/InterpC-armv5te-vfp.cpp
+++ b/vm/mterp/out/InterpC-armv5te-vfp.cpp
@@ -102,7 +102,7 @@
{ \
char* desc; \
desc = dexProtoCopyMethodDescriptor(&curMethod->prototype); \
- LOGE("Invalid branch %d at 0x%04x in %s.%s %s", \
+ ALOGE("Invalid branch %d at 0x%04x in %s.%s %s", \
myoff, (int) (pc - curMethod->insns), \
curMethod->clazz->descriptor, curMethod->name, desc); \
free(desc); \
@@ -321,14 +321,14 @@ static inline bool checkForNull(Object* obj)
}
#ifdef WITH_EXTRA_OBJECT_VALIDATION
if (!dvmIsHeapAddress(obj)) {
- LOGE("Invalid object %p", obj);
+ ALOGE("Invalid object %p", obj);
dvmAbort();
}
#endif
#ifndef NDEBUG
if (obj->clazz == NULL || ((u4) obj->clazz) <= 65536) {
/* probable heap corruption */
- LOGE("Invalid object class %p (in %p)", obj->clazz, obj);
+ ALOGE("Invalid object class %p (in %p)", obj->clazz, obj);
dvmAbort();
}
#endif
@@ -353,14 +353,14 @@ static inline bool checkForNullExportPC(Object* obj, u4* fp, const u2* pc)
}
#ifdef WITH_EXTRA_OBJECT_VALIDATION
if (!dvmIsHeapAddress(obj)) {
- LOGE("Invalid object %p", obj);
+ ALOGE("Invalid object %p", obj);
dvmAbort();
}
#endif
#ifndef NDEBUG
if (obj->clazz == NULL || ((u4) obj->clazz) <= 65536) {
/* probable heap corruption */
- LOGE("Invalid object class %p (in %p)", obj->clazz, obj);
+ ALOGE("Invalid object class %p (in %p)", obj->clazz, obj);
dvmAbort();
}
#endif
diff --git a/vm/mterp/out/InterpC-armv5te.cpp b/vm/mterp/out/InterpC-armv5te.cpp
index 870e6829a..b06e25df9 100644
--- a/vm/mterp/out/InterpC-armv5te.cpp
+++ b/vm/mterp/out/InterpC-armv5te.cpp
@@ -102,7 +102,7 @@
{ \
char* desc; \
desc = dexProtoCopyMethodDescriptor(&curMethod->prototype); \
- LOGE("Invalid branch %d at 0x%04x in %s.%s %s", \
+ ALOGE("Invalid branch %d at 0x%04x in %s.%s %s", \
myoff, (int) (pc - curMethod->insns), \
curMethod->clazz->descriptor, curMethod->name, desc); \
free(desc); \
@@ -321,14 +321,14 @@ static inline bool checkForNull(Object* obj)
}
#ifdef WITH_EXTRA_OBJECT_VALIDATION
if (!dvmIsHeapAddress(obj)) {
- LOGE("Invalid object %p", obj);
+ ALOGE("Invalid object %p", obj);
dvmAbort();
}
#endif
#ifndef NDEBUG
if (obj->clazz == NULL || ((u4) obj->clazz) <= 65536) {
/* probable heap corruption */
- LOGE("Invalid object class %p (in %p)", obj->clazz, obj);
+ ALOGE("Invalid object class %p (in %p)", obj->clazz, obj);
dvmAbort();
}
#endif
@@ -353,14 +353,14 @@ static inline bool checkForNullExportPC(Object* obj, u4* fp, const u2* pc)
}
#ifdef WITH_EXTRA_OBJECT_VALIDATION
if (!dvmIsHeapAddress(obj)) {
- LOGE("Invalid object %p", obj);
+ ALOGE("Invalid object %p", obj);
dvmAbort();
}
#endif
#ifndef NDEBUG
if (obj->clazz == NULL || ((u4) obj->clazz) <= 65536) {
/* probable heap corruption */
- LOGE("Invalid object class %p (in %p)", obj->clazz, obj);
+ ALOGE("Invalid object class %p (in %p)", obj->clazz, obj);
dvmAbort();
}
#endif
diff --git a/vm/mterp/out/InterpC-armv7-a-neon.cpp b/vm/mterp/out/InterpC-armv7-a-neon.cpp
index bd9fe284b..250c2dc0c 100644
--- a/vm/mterp/out/InterpC-armv7-a-neon.cpp
+++ b/vm/mterp/out/InterpC-armv7-a-neon.cpp
@@ -102,7 +102,7 @@
{ \
char* desc; \
desc = dexProtoCopyMethodDescriptor(&curMethod->prototype); \
- LOGE("Invalid branch %d at 0x%04x in %s.%s %s", \
+ ALOGE("Invalid branch %d at 0x%04x in %s.%s %s", \
myoff, (int) (pc - curMethod->insns), \
curMethod->clazz->descriptor, curMethod->name, desc); \
free(desc); \
@@ -321,14 +321,14 @@ static inline bool checkForNull(Object* obj)
}
#ifdef WITH_EXTRA_OBJECT_VALIDATION
if (!dvmIsHeapAddress(obj)) {
- LOGE("Invalid object %p", obj);
+ ALOGE("Invalid object %p", obj);
dvmAbort();
}
#endif
#ifndef NDEBUG
if (obj->clazz == NULL || ((u4) obj->clazz) <= 65536) {
/* probable heap corruption */
- LOGE("Invalid object class %p (in %p)", obj->clazz, obj);
+ ALOGE("Invalid object class %p (in %p)", obj->clazz, obj);
dvmAbort();
}
#endif
@@ -353,14 +353,14 @@ static inline bool checkForNullExportPC(Object* obj, u4* fp, const u2* pc)
}
#ifdef WITH_EXTRA_OBJECT_VALIDATION
if (!dvmIsHeapAddress(obj)) {
- LOGE("Invalid object %p", obj);
+ ALOGE("Invalid object %p", obj);
dvmAbort();
}
#endif
#ifndef NDEBUG
if (obj->clazz == NULL || ((u4) obj->clazz) <= 65536) {
/* probable heap corruption */
- LOGE("Invalid object class %p (in %p)", obj->clazz, obj);
+ ALOGE("Invalid object class %p (in %p)", obj->clazz, obj);
dvmAbort();
}
#endif
diff --git a/vm/mterp/out/InterpC-armv7-a.cpp b/vm/mterp/out/InterpC-armv7-a.cpp
index 54b450932..747c4cf66 100644
--- a/vm/mterp/out/InterpC-armv7-a.cpp
+++ b/vm/mterp/out/InterpC-armv7-a.cpp
@@ -102,7 +102,7 @@
{ \
char* desc; \
desc = dexProtoCopyMethodDescriptor(&curMethod->prototype); \
- LOGE("Invalid branch %d at 0x%04x in %s.%s %s", \
+ ALOGE("Invalid branch %d at 0x%04x in %s.%s %s", \
myoff, (int) (pc - curMethod->insns), \
curMethod->clazz->descriptor, curMethod->name, desc); \
free(desc); \
@@ -321,14 +321,14 @@ static inline bool checkForNull(Object* obj)
}
#ifdef WITH_EXTRA_OBJECT_VALIDATION
if (!dvmIsHeapAddress(obj)) {
- LOGE("Invalid object %p", obj);
+ ALOGE("Invalid object %p", obj);
dvmAbort();
}
#endif
#ifndef NDEBUG
if (obj->clazz == NULL || ((u4) obj->clazz) <= 65536) {
/* probable heap corruption */
- LOGE("Invalid object class %p (in %p)", obj->clazz, obj);
+ ALOGE("Invalid object class %p (in %p)", obj->clazz, obj);
dvmAbort();
}
#endif
@@ -353,14 +353,14 @@ static inline bool checkForNullExportPC(Object* obj, u4* fp, const u2* pc)
}
#ifdef WITH_EXTRA_OBJECT_VALIDATION
if (!dvmIsHeapAddress(obj)) {
- LOGE("Invalid object %p", obj);
+ ALOGE("Invalid object %p", obj);
dvmAbort();
}
#endif
#ifndef NDEBUG
if (obj->clazz == NULL || ((u4) obj->clazz) <= 65536) {
/* probable heap corruption */
- LOGE("Invalid object class %p (in %p)", obj->clazz, obj);
+ ALOGE("Invalid object class %p (in %p)", obj->clazz, obj);
dvmAbort();
}
#endif
diff --git a/vm/mterp/c/gotoTargets.cpp b/vm/mterp/c/gotoTargets.cpp
index 6df3b9a37..b335273ec 100644
--- a/vm/mterp/c/gotoTargets.cpp
+++ b/vm/mterp/c/gotoTargets.cpp
@@ -65,7 +65,7 @@ GOTO_TARGET(filledNewArray, bool methodCallRange, bool)
GOTO_exceptionThrown();
} else if (typeCh != 'L' && typeCh != '[' && typeCh != 'I') {
/* TODO: requires multiple "fill in" loops with different widths */
- LOGE("non-int primitives not implemented");
+ ALOGE("non-int primitives not implemented");
dvmThrowInternalError(
"filled-new-array not implemented for anything but 'int'");
GOTO_exceptionThrown();
@@ -582,7 +582,7 @@ GOTO_TARGET(returnFromMethod)
{
FINISH(3);
} else {
//LOGE("Unknown invoke instr %02x at %d",
// invokeInstr, (int) (pc - curMethod->insns));
assert(false);
}
@@ -959,7 +959,7 @@ GOTO_TARGET(invokeMethod, bool methodCallRange, const Method* _methodToCall,
{
FINISH(3);
} else {
//LOGE("Unknown invoke instr %02x at %d",
// invokeInstr, (int) (pc - curMethod->insns));
assert(false);
}
@@ -582,7 +582,7 @@ GOTO_TARGET(returnFromMethod)
FINISH(3);
} else {
- //LOGE("Unknown invoke instr %02x at %d",
+ //ALOGE("Unknown invoke instr %02x at %d",
// invokeInstr, (int) (pc - curMethod->insns));
assert(false);
@@ -959,7 +959,7 @@ GOTO_TARGET(invokeMethod, bool methodCallRange, const Method* _methodToCall,
FINISH(3);
} else {
- //LOGE("Unknown invoke instr %02x at %d",
+ //ALOGE("Unknown invoke instr %02x at %d",
// invokeInstr, (int) (pc - curMethod->insns));
assert(false);
diff --git a/vm/mterp/out/InterpC-allstubs.cpp b/vm/mterp/out/InterpC-allstubs.cpp
index b266e61f0..5a78dc4ad 100644
--- a/vm/mterp/out/InterpC-allstubs.cpp
+++ b/vm/mterp/out/InterpC-allstubs.cpp
@@ -102,7 +102,7 @@
{ \
char* desc; \
desc = dexProtoCopyMethodDescriptor(&curMethod->prototype); \
- LOGE("Invalid branch %d at 0x%04x in %s.%s %s", \
+ ALOGE("Invalid branch %d at 0x%04x in %s.%s %s", \
myoff, (int) (pc - curMethod->insns), \
curMethod->clazz->descriptor, curMethod->name, desc); \
free(desc); \
@@ -321,14 +321,14 @@ static inline bool checkForNull(Object* obj)
}
#ifdef WITH_EXTRA_OBJECT_VALIDATION
if (!dvmIsHeapAddress(obj)) {
- LOGE("Invalid object %p", obj);
+ ALOGE("Invalid object %p", obj);
dvmAbort();
}
#endif
#ifndef NDEBUG
if (obj->clazz == NULL || ((u4) obj->clazz) <= 65536) {
/* probable heap corruption */
- LOGE("Invalid object class %p (in %p)", obj->clazz, obj);
+ ALOGE("Invalid object class %p (in %p)", obj->clazz, obj);
dvmAbort();
}
#endif
@@ -353,14 +353,14 @@ static inline bool checkForNullExportPC(Object* obj, u4* fp, const u2* pc)
}
#ifdef WITH_EXTRA_OBJECT_VALIDATION
if (!dvmIsHeapAddress(obj)) {
- LOGE("Invalid object %p", obj);
+ ALOGE("Invalid object %p", obj);
dvmAbort();
}
#endif
#ifndef NDEBUG
if (obj->clazz == NULL || ((u4) obj->clazz) <= 65536) {
/* probable heap corruption */
- LOGE("Invalid object class %p (in %p)", obj->clazz, obj);
+ ALOGE("Invalid object class %p (in %p)", obj->clazz, obj);
dvmAbort();
}
#endif
@@ -3005,7 +3005,7 @@ HANDLE_OPCODE(OP_UNUSED_FF)
/*
* In portable interp, most unused opcodes will fall through to here.
*/
- LOGE("unknown opcode 0x%02x\n", INST_INST(inst));
+ ALOGE("unknown opcode 0x%02x\n", INST_INST(inst));
dvmAbort();
FINISH(1);
OP_END
@@ -3141,7 +3141,7 @@ GOTO_TARGET(filledNewArray, bool methodCallRange, bool)
GOTO_exceptionThrown();
} else if (typeCh != 'L' && typeCh != '[' && typeCh != 'I') {
/* TODO: requires multiple "fill in" loops with different widths */
- LOGE("non-int primitives not implemented");
+ ALOGE("non-int primitives not implemented");
dvmThrowInternalError(
"filled-new-array not implemented for anything but 'int'");
GOTO_exceptionThrown();
@@ -3658,7 +3658,7 @@ GOTO_TARGET(returnFromMethod)
{
FINISH(3);
} else {
//LOGE("Unknown invoke instr %02x at %d",
// invokeInstr, (int) (pc - curMethod->insns));
assert(false);
}
@@ -4035,7 +4035,7 @@ GOTO_TARGET(invokeMethod, bool methodCallRange, const Method* _methodToCall,
{
FINISH(3);
} else {
//LOGE("Unknown invoke instr %02x at %d",
// invokeInstr, (int) (pc - curMethod->insns));
assert(false);
}
@@ -3658,7 +3658,7 @@ GOTO_TARGET(returnFromMethod)
FINISH(3);
} else {
- //LOGE("Unknown invoke instr %02x at %d",
+ //ALOGE("Unknown invoke instr %02x at %d",
// invokeInstr, (int) (pc - curMethod->insns));
assert(false);
@@ -4035,7 +4035,7 @@ GOTO_TARGET(invokeMethod, bool methodCallRange, const Method* _methodToCall,
FINISH(3);
} else {
- //LOGE("Unknown invoke instr %02x at %d",
+ //ALOGE("Unknown invoke instr %02x at %d",
// invokeInstr, (int) (pc - curMethod->insns));
assert(false);
diff --git a/vm/mterp/out/InterpC-portable.cpp b/vm/mterp/out/InterpC-portable.cpp
index 2abcb8d9b..b32432de7 100644
--- a/vm/mterp/out/InterpC-portable.cpp
+++ b/vm/mterp/out/InterpC-portable.cpp
@@ -102,7 +102,7 @@
{ \
char* desc; \
desc = dexProtoCopyMethodDescriptor(&curMethod->prototype); \
- LOGE("Invalid branch %d at 0x%04x in %s.%s %s", \
+ ALOGE("Invalid branch %d at 0x%04x in %s.%s %s", \
myoff, (int) (pc - curMethod->insns), \
curMethod->clazz->descriptor, curMethod->name, desc); \
free(desc); \
@@ -321,14 +321,14 @@ static inline bool checkForNull(Object* obj)
}
#ifdef WITH_EXTRA_OBJECT_VALIDATION
if (!dvmIsHeapAddress(obj)) {
- LOGE("Invalid object %p", obj);
+ ALOGE("Invalid object %p", obj);
dvmAbort();
}
#endif
#ifndef NDEBUG
if (obj->clazz == NULL || ((u4) obj->clazz) <= 65536) {
/* probable heap corruption */
- LOGE("Invalid object class %p (in %p)", obj->clazz, obj);
+ ALOGE("Invalid object class %p (in %p)", obj->clazz, obj);
dvmAbort();
}
#endif
@@ -353,14 +353,14 @@ static inline bool checkForNullExportPC(Object* obj, u4* fp, const u2* pc)
}
#ifdef WITH_EXTRA_OBJECT_VALIDATION
if (!dvmIsHeapAddress(obj)) {
- LOGE("Invalid object %p", obj);
+ ALOGE("Invalid object %p", obj);
dvmAbort();
}
#endif
#ifndef NDEBUG
if (obj->clazz == NULL || ((u4) obj->clazz) <= 65536) {
/* probable heap corruption */
- LOGE("Invalid object class %p (in %p)", obj->clazz, obj);
+ ALOGE("Invalid object class %p (in %p)", obj->clazz, obj);
dvmAbort();
}
#endif
@@ -3018,7 +3018,7 @@ HANDLE_OPCODE(OP_UNUSED_FF)
/*
* In portable interp, most unused opcodes will fall through to here.
*/
- LOGE("unknown opcode 0x%02x\n", INST_INST(inst));
+ ALOGE("unknown opcode 0x%02x\n", INST_INST(inst));
dvmAbort();
FINISH(1);
OP_END
@@ -3091,7 +3091,7 @@ GOTO_TARGET(filledNewArray, bool methodCallRange, bool)
GOTO_exceptionThrown();
} else if (typeCh != 'L' && typeCh != '[' && typeCh != 'I') {
/* TODO: requires multiple "fill in" loops with different widths */
- LOGE("non-int primitives not implemented");
+ ALOGE("non-int primitives not implemented");
dvmThrowInternalError(
"filled-new-array not implemented for anything but 'int'");
GOTO_exceptionThrown();
@@ -3608,7 +3608,7 @@ GOTO_TARGET(returnFromMethod)
{
FINISH(3);
} else {
//LOGE("Unknown invoke instr %02x at %d",
// invokeInstr, (int) (pc - curMethod->insns));
assert(false);
}
@@ -3985,7 +3985,7 @@ GOTO_TARGET(invokeMethod, bool methodCallRange, const Method* _methodToCall,
{
FINISH(3);
} else {
//LOGE("Unknown invoke instr %02x at %d",
// invokeInstr, (int) (pc - curMethod->insns));
assert(false);
}
@@ -3608,7 +3608,7 @@ GOTO_TARGET(returnFromMethod)
FINISH(3);
} else {
- //LOGE("Unknown invoke instr %02x at %d",
+ //ALOGE("Unknown invoke instr %02x at %d",
// invokeInstr, (int) (pc - curMethod->insns));
assert(false);
@@ -3985,7 +3985,7 @@ GOTO_TARGET(invokeMethod, bool methodCallRange, const Method* _methodToCall,
FINISH(3);
} else {
- //LOGE("Unknown invoke instr %02x at %d",
+ //ALOGE("Unknown invoke instr %02x at %d",
// invokeInstr, (int) (pc - curMethod->insns));
assert(false);
diff --git a/vm/mterp/out/InterpC-x86-atom.cpp b/vm/mterp/out/InterpC-x86-atom.cpp
index b204ff930..00a1e5019 100644
--- a/vm/mterp/out/InterpC-x86-atom.cpp
+++ b/vm/mterp/out/InterpC-x86-atom.cpp
@@ -102,7 +102,7 @@
{ \
char* desc; \
desc = dexProtoCopyMethodDescriptor(&curMethod->prototype); \
- LOGE("Invalid branch %d at 0x%04x in %s.%s %s", \
+ ALOGE("Invalid branch %d at 0x%04x in %s.%s %s", \
myoff, (int) (pc - curMethod->insns), \
curMethod->clazz->descriptor, curMethod->name, desc); \
free(desc); \
@@ -321,14 +321,14 @@ static inline bool checkForNull(Object* obj)
}
#ifdef WITH_EXTRA_OBJECT_VALIDATION
if (!dvmIsHeapAddress(obj)) {
- LOGE("Invalid object %p", obj);
+ ALOGE("Invalid object %p", obj);
dvmAbort();
}
#endif
#ifndef NDEBUG
if (obj->clazz == NULL || ((u4) obj->clazz) <= 65536) {
/* probable heap corruption */
- LOGE("Invalid object class %p (in %p)", obj->clazz, obj);
+ ALOGE("Invalid object class %p (in %p)", obj->clazz, obj);
dvmAbort();
}
#endif
@@ -353,14 +353,14 @@ static inline bool checkForNullExportPC(Object* obj, u4* fp, const u2* pc)
}
#ifdef WITH_EXTRA_OBJECT_VALIDATION
if (!dvmIsHeapAddress(obj)) {
- LOGE("Invalid object %p", obj);
+ ALOGE("Invalid object %p", obj);
dvmAbort();
}
#endif
#ifndef NDEBUG
if (obj->clazz == NULL || ((u4) obj->clazz) <= 65536) {
/* probable heap corruption */
- LOGE("Invalid object class %p (in %p)", obj->clazz, obj);
+ ALOGE("Invalid object class %p (in %p)", obj->clazz, obj);
dvmAbort();
}
#endif
@@ -1380,7 +1380,7 @@ GOTO_TARGET(filledNewArray, bool methodCallRange, bool)
GOTO_exceptionThrown();
} else if (typeCh != 'L' && typeCh != '[' && typeCh != 'I') {
/* TODO: requires multiple "fill in" loops with different widths */
- LOGE("non-int primitives not implemented");
+ ALOGE("non-int primitives not implemented");
dvmThrowInternalError(
"filled-new-array not implemented for anything but 'int'");
GOTO_exceptionThrown();
@@ -1897,7 +1897,7 @@ GOTO_TARGET(returnFromMethod)
{
FINISH(3);
} else {
//LOGE("Unknown invoke instr %02x at %d",
// invokeInstr, (int) (pc - curMethod->insns));
assert(false);
}
@@ -2274,7 +2274,7 @@ GOTO_TARGET(invokeMethod, bool methodCallRange, const Method* _methodToCall,
{
FINISH(3);
} else {
//LOGE("Unknown invoke instr %02x at %d",
// invokeInstr, (int) (pc - curMethod->insns));
assert(false);
}
@@ -1897,7 +1897,7 @@ GOTO_TARGET(returnFromMethod)
FINISH(3);
} else {
- //LOGE("Unknown invoke instr %02x at %d",
+ //ALOGE("Unknown invoke instr %02x at %d",
// invokeInstr, (int) (pc - curMethod->insns));
assert(false);
@@ -2274,7 +2274,7 @@ GOTO_TARGET(invokeMethod, bool methodCallRange, const Method* _methodToCall,
FINISH(3);
} else {
- //LOGE("Unknown invoke instr %02x at %d",
+ //ALOGE("Unknown invoke instr %02x at %d",
// invokeInstr, (int) (pc - curMethod->insns));
assert(false);
diff --git a/vm/mterp/out/InterpC-x86.cpp b/vm/mterp/out/InterpC-x86.cpp
index 616e31f0e..ea441d7a6 100644
--- a/vm/mterp/out/InterpC-x86.cpp
+++ b/vm/mterp/out/InterpC-x86.cpp
@@ -102,7 +102,7 @@
{ \
char* desc; \
desc = dexProtoCopyMethodDescriptor(&curMethod->prototype); \
- LOGE("Invalid branch %d at 0x%04x in %s.%s %s", \
+ ALOGE("Invalid branch %d at 0x%04x in %s.%s %s", \
myoff, (int) (pc - curMethod->insns), \
curMethod->clazz->descriptor, curMethod->name, desc); \
free(desc); \
@@ -321,14 +321,14 @@ static inline bool checkForNull(Object* obj)
}
#ifdef WITH_EXTRA_OBJECT_VALIDATION
if (!dvmIsHeapAddress(obj)) {
- LOGE("Invalid object %p", obj);
+ ALOGE("Invalid object %p", obj);
dvmAbort();
}
#endif
#ifndef NDEBUG
if (obj->clazz == NULL || ((u4) obj->clazz) <= 65536) {
/* probable heap corruption */
- LOGE("Invalid object class %p (in %p)", obj->clazz, obj);
+ ALOGE("Invalid object class %p (in %p)", obj->clazz, obj);
dvmAbort();
}
#endif
@@ -353,14 +353,14 @@ static inline bool checkForNullExportPC(Object* obj, u4* fp, const u2* pc)
}
#ifdef WITH_EXTRA_OBJECT_VALIDATION
if (!dvmIsHeapAddress(obj)) {
- LOGE("Invalid object %p", obj);
+ ALOGE("Invalid object %p", obj);
dvmAbort();
}
#endif
#ifndef NDEBUG
if (obj->clazz == NULL || ((u4) obj->clazz) <= 65536) {
/* probable heap corruption */
- LOGE("Invalid object class %p (in %p)", obj->clazz, obj);
+ ALOGE("Invalid object class %p (in %p)", obj->clazz, obj);
dvmAbort();
}
#endif
@@ -1322,7 +1322,7 @@ GOTO_TARGET(filledNewArray, bool methodCallRange, bool)
GOTO_exceptionThrown();
} else if (typeCh != 'L' && typeCh != '[' && typeCh != 'I') {
/* TODO: requires multiple "fill in" loops with different widths */
- LOGE("non-int primitives not implemented");
+ ALOGE("non-int primitives not implemented");
dvmThrowInternalError(
"filled-new-array not implemented for anything but 'int'");
GOTO_exceptionThrown();
@@ -1839,7 +1839,7 @@ GOTO_TARGET(returnFromMethod)
{
FINISH(3);
} else {
//LOGE("Unknown invoke instr %02x at %d",
// invokeInstr, (int) (pc - curMethod->insns));
assert(false);
}
@@ -2216,7 +2216,7 @@ GOTO_TARGET(invokeMethod, bool methodCallRange, const Method* _methodToCall,
{
FINISH(3);
} else {
//LOGE("Unknown invoke instr %02x at %d",
// invokeInstr, (int) (pc - curMethod->insns));
assert(false);
}
@@ -1839,7 +1839,7 @@ GOTO_TARGET(returnFromMethod)
FINISH(3);
} else {
- //LOGE("Unknown invoke instr %02x at %d",
+ //ALOGE("Unknown invoke instr %02x at %d",
// invokeInstr, (int) (pc - curMethod->insns));
assert(false);
@@ -2216,7 +2216,7 @@ GOTO_TARGET(invokeMethod, bool methodCallRange, const Method* _methodToCall,
FINISH(3);
} else {
- //LOGE("Unknown invoke instr %02x at %d",
+ //ALOGE("Unknown invoke instr %02x at %d",
// invokeInstr, (int) (pc - curMethod->insns));
assert(false);